@@ -30,6 +30,9 @@ def restartIntoNewApplication():
     args = [sys.executable, '-m', 'millconnect.gui']
     if len(sys.argv) > 1:
         args += sys.argv[1:]
+
+    for i, arg in enumerate(args):
+        args[i] = f'"{arg}"'
     
     logger.info(f'Re-spawning: {sys.executable} {args}')
     os.execv(sys.executable, args)
